Struct DeflateDecoder
struct DeflateDecoder<R> { ... }
A DEFLATE decoder, or decompressor.
This structure implements a Read interface. When read from, it reads
compressed data from the underlying BufRead and provides the uncompressed data.
After reading a single member of the DEFLATE data this reader will return
Ok(0) even if there are more bytes available in the underlying reader.
If you need the following bytes, call into_inner() after Ok(0) to
recover the underlying reader.
Examples
use *;
use io;
# use Compression;
# use DeflateEncoder;
use DeflateDecoder;
#
// Uncompresses a Deflate Encoded vector of bytes and returns a string or error
// Here &[u8] implements Read
Implementations
impl<R> DeflateDecoder<R>
fn reset(self: &mut Self, r: R) -> RResets the state of this decoder entirely, swapping out the input stream for another.
This will reset the internal state of this decoder and replace the input stream with the one provided, returning the previous input stream. Future data read from this decoder will be the decompressed version of
r's data.fn reset_data(self: &mut Self)Resets the state of this decoder's data
This will reset the internal state of this decoder. It will continue reading from the same stream.
fn get_ref(self: &Self) -> &RAcquires a reference to the underlying stream
fn get_mut(self: &mut Self) -> &mut RAcquires a mutable reference to the underlying stream
Note that mutation of the stream may result in surprising results if this decoder is continued to be used.
fn into_inner(self: Self) -> RConsumes this decoder, returning the underlying reader.
fn total_in(self: &Self) -> u64Returns the number of bytes that the decompressor has consumed.
Note that this will likely be smaller than what the decompressor actually read from the underlying stream due to buffering.
fn total_out(self: &Self) -> u64Returns the number of bytes that the decompressor has produced.
impl<R: BufRead> DeflateDecoder<R>
fn new(r: R) -> DeflateDecoder<R>Creates a new decoder which will decompress data read from the given stream.
impl<R> Freeze for DeflateDecoder<R>
impl<R> RefUnwindSafe for DeflateDecoder<R>
impl<R> Send for DeflateDecoder<R>
impl<R> Sync for DeflateDecoder<R>
impl<R> Unpin for DeflateDecoder<R>
impl<R> UnsafeUnpin for DeflateDecoder<R>
impl<R> UnwindSafe for DeflateDecoder<R>
impl<R: $crate::fmt::Debug> Debug for DeflateDecoder<R>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<R: BufRead> Read for DeflateDecoder<R>
fn read(self: &mut Self, into: &mut [u8]) -> Result<usize>
impl<T> Any for DeflateDecoder<R>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DeflateDecoder<R>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DeflateDecoder<R>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for DeflateDecoder<R>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for DeflateDecoder<R>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DeflateDecoder<R>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DeflateDecoder<R>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<W: BufRead + Write> Write for DeflateDecoder<W>
fn write(self: &mut Self, buf: &[u8]) -> Result<usize>fn flush(self: &mut Self) -> Result<()>