pub struct MultiGzDecoder<R>(/* private fields */);Expand description
A gzip streaming decoder that decodes a gzip file that may have multiple members.
This structure implements a Read interface. When read from, it reads
compressed data from the underlying BufRead and provides the uncompressed data.
A gzip file consists of a series of members concatenated one after another. MultiGzDecoder decodes all members from the data and only returns Ok(0) when the underlying reader does. For a file, this reads to the end of the file.
To handle members separately, see GzDecoder or read more in the introduction.
Examples
use std::io::prelude::*;
use std::io;
use flate2::bufread::MultiGzDecoder;
// Uncompresses a Gz Encoded vector of bytes and returns a string or error
// Here &[u8] implements BufRead
fn decode_reader(bytes: Vec<u8>) -> io::Result<String> {
let mut gz = MultiGzDecoder::new(&bytes[..]);
let mut s = String::new();
gz.read_to_string(&mut s)?;
Ok(s)
}Implementations
Sourceimpl<R: BufRead> MultiGzDecoder<R>
impl<R: BufRead> MultiGzDecoder<R>
Sourcepub fn new(r: R) -> MultiGzDecoder<R> ⓘ
pub fn new(r: R) -> MultiGzDecoder<R> ⓘ
Creates a new decoder from the given reader, immediately parsing the (first) gzip header. If the gzip stream contains multiple members all will be decoded.
Sourceimpl<R> MultiGzDecoder<R>
impl<R> MultiGzDecoder<R>
Sourcepub fn header(&self) -> Option<&GzHeader>
pub fn header(&self) -> Option<&GzHeader>
Returns the current header associated with this stream, if it’s valid
Sourcepub fn get_mut(&mut self) -> &mut R
pub fn get_mut(&mut self) -> &mut R
Acquires a mutable reference to the underlying stream.
The underlying reader may be mutated as long as its unread input and current position are preserved for subsequent reads by this decoder.
To process a new stream, wait for this decoder to reach EOF and create a new decoder; replacing the reader directly does not reset it.
Sourcepub fn into_inner(self) -> R
pub fn into_inner(self) -> R
Consumes this decoder, returning the underlying reader.