Struct ZlibDecoder

struct ZlibDecoder<R> { ... }

A ZLIB decoder, or decompressor.

This structure implements a Read interface. When read from, it reads compressed data from the underlying BufRead and provides the uncompressed data.

After reading a single member of the ZLIB data this reader will return Ok(0) even if there are more bytes available in the underlying reader. If you need the following bytes, call into_inner() after Ok(0) to recover the underlying reader.

Examples

use std::io::prelude::*;
use std::io;
# use flate2::Compression;
# use flate2::write::ZlibEncoder;
use flate2::bufread::ZlibDecoder;

# fn main() {
# let mut e = ZlibEncoder::new(Vec::new(), Compression::default());
# e.write_all(b"Hello World").unwrap();
# let bytes = e.finish().unwrap();
# println!("{}", decode_bufreader(bytes).unwrap());
# }
#
// Uncompresses a Zlib Encoded vector of bytes and returns a string or error
// Here &[u8] implements BufRead

fn decode_bufreader(bytes: Vec<u8>) -> io::Result<String> {
    let mut z = ZlibDecoder::new(&bytes[..]);
    let mut s = String::new();
    z.read_to_string(&mut s)?;
    Ok(s)
}

Implementations

impl<R> ZlibDecoder<R>

fn reset(self: &mut Self, r: R) -> R

Resets the state of this decoder entirely, swapping out the input stream for another.

This will reset the internal state of this decoder and replace the input stream with the one provided, returning the previous input stream. Future data read from this decoder will be the decompressed version of r's data.

fn get_ref(self: &Self) -> &R

Acquires a reference to the underlying stream

fn get_mut(self: &mut Self) -> &mut R

Acquires a mutable reference to the underlying stream

Note that mutation of the stream may result in surprising results if this decoder is continued to be used.

fn into_inner(self: Self) -> R

Consumes this decoder, returning the underlying reader.

fn total_in(self: &Self) -> u64

Returns the number of bytes that the decompressor has consumed.

Note that this will likely be smaller than what the decompressor actually read from the underlying stream due to buffering.

fn total_out(self: &Self) -> u64

Returns the number of bytes that the decompressor has produced.

impl<R: BufRead> ZlibDecoder<R>

fn new(r: R) -> ZlibDecoder<R>

Creates a new decoder which will decompress data read from the given stream.

fn new_with_decompress(r: R, decompression: Decompress) -> ZlibDecoder<R>

Creates a new decoder which will decompress data read from the given stream, using the given decompression settings.

impl<R> Freeze for ZlibDecoder<R>

impl<R> RefUnwindSafe for ZlibDecoder<R>

impl<R> Send for ZlibDecoder<R>

impl<R> Sync for ZlibDecoder<R>

impl<R> Unpin for ZlibDecoder<R>

impl<R> UnsafeUnpin for ZlibDecoder<R>

impl<R> UnwindSafe for ZlibDecoder<R>

impl<R: $crate::fmt::Debug> Debug for ZlibDecoder<R>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<R: BufRead + Write> Write for ZlibDecoder<R>

fn write(self: &mut Self, buf: &[u8]) -> Result<usize>
fn flush(self: &mut Self) -> Result<()>

impl<R: BufRead> Read for ZlibDecoder<R>

fn read(self: &mut Self, into: &mut [u8]) -> Result<usize>

impl<T> Any for ZlibDecoder<R>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ZlibDecoder<R>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ZlibDecoder<R>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for ZlibDecoder<R>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for ZlibDecoder<R>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ZlibDecoder<R>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ZlibDecoder<R>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>