Enum FlushDecompress

enum FlushDecompress

Values which indicate the form of flushing to be used when decompressing in-memory data.

Variants

None

A typical parameter for passing to compression/decompression functions, this indicates that the underlying stream to decide how much data to accumulate before producing output in order to maximize compression.

Sync

All pending output is flushed to the output buffer and the output is aligned on a byte boundary so that the decompressor can get all input data available so far.

Flushing may degrade compression for some compression algorithms and so it should only be used when necessary. This will complete the current deflate block and follow it with an empty stored block.

Finish

Pending input is processed and pending output is flushed.

The return value may indicate that the stream is not yet done and more data has yet to be processed.

Implementations

impl Clone for FlushDecompress

fn clone(self: &Self) -> FlushDecompress

impl Copy for FlushDecompress

impl Debug for FlushDecompress

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for FlushDecompress

impl Freeze for FlushDecompress

impl PartialEq for FlushDecompress

fn eq(self: &Self, other: &FlushDecompress) -> bool

impl RefUnwindSafe for FlushDecompress

impl Send for FlushDecompress

impl StructuralPartialEq for FlushDecompress

impl Sync for FlushDecompress

impl Unpin for FlushDecompress

impl UnsafeUnpin for FlushDecompress

impl UnwindSafe for FlushDecompress

impl<T> Any for FlushDecompress

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for FlushDecompress

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for FlushDecompress

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for FlushDecompress

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for FlushDecompress

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for FlushDecompress

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for FlushDecompress

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for FlushDecompress

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for FlushDecompress

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>