Enum Status

enum Status

Possible status results of compressing some data or successfully decompressing a block of data.

Variants

Ok

Indicates success.

Means that more input may be needed but isn't available and/or there's more output to be written but the output buffer is full.

BufError

Indicates that forward progress is not possible due to input or output buffers being empty.

For compression it means the input buffer needs some more data or the output buffer needs to be freed up before trying again.

For decompression this means that more input is needed to continue or the output buffer isn't large enough to contain the result. The function can be called again after fixing both.

StreamEnd

Indicates that all input has been consumed and all output bytes have been written. Decompression/compression should not be called again.

For decompression with zlib streams the adler-32 of the decompressed data has also been verified.

Implementations

impl Clone for Status

fn clone(self: &Self) -> Status

impl Copy for Status

impl Debug for Status

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for Status

impl Freeze for Status

impl PartialEq for Status

fn eq(self: &Self, other: &Status) -> bool

impl RefUnwindSafe for Status

impl Send for Status

impl StructuralPartialEq for Status

impl Sync for Status

impl Unpin for Status

impl UnsafeUnpin for Status

impl UnwindSafe for Status

impl<T> Any for Status

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Status

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Status

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Status

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Status

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Status

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Status

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Status

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Status

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>