GzDecoder

Struct GzDecoder 

pub struct GzDecoder<R> { /* private fields */ }
A decoder for a single member of a gzip file.

This structure implements a Read interface. When read from, it reads compressed data from the underlying Read and provides the uncompressed data.

After reading a single member of the gzip data this reader will return Ok(0) even if there are more bytes available in the underlying reader. GzDecoder may have read additional bytes past the end of the gzip data. If you need the following bytes, wrap the Reader in a std::io::BufReader and use bufread::GzDecoder instead.

To handle gzip files that may have multiple members, see MultiGzDecoder or read more in the introduction.

Examples

use std::io::prelude::*;
use std::io;
use flate2::read::GzDecoder;

// Uncompresses a Gz Encoded vector of bytes and returns a string or error
// Here &[u8] implements Read

fn decode_reader(bytes: Vec<u8>) -> io::Result<String> {
   let mut gz = GzDecoder::new(&bytes[..]);
   let mut s = String::new();
   gz.read_to_string(&mut s)?;
   Ok(s)
}

Implementations

Source

impl<R: Read> GzDecoder<R>

pub fn new(r: R) -> GzDecoder<R> ⓘ

Creates a new decoder from the given reader, immediately parsing the gzip header.

Source

impl<R> GzDecoder<R>

pub fn header(&self) -> Option<&GzHeader>

Returns the header associated with this stream, if it was valid.

pub fn get_ref(&self) -> &R

Acquires a reference to the underlying reader.

Note that the decoder may have read past the end of the gzip data. To prevent this use bufread::GzDecoder instead.

pub fn get_mut(&mut self) -> &mut R

Acquires a mutable reference to the underlying stream.

The underlying reader may be mutated as long as its unread input and current position are preserved for subsequent reads by this decoder.

To process a new stream, wait for this decoder to reach EOF and use reset; replacing the reader directly does not reset it.

Note that the decoder may have read past the end of the gzip data. To prevent this use bufread::GzDecoder instead.

pub fn into_inner(self) -> R

Consumes this decoder, returning the underlying reader.

Note that the decoder may have read past the end of the gzip data. Subsequent reads will skip those bytes. To prevent this use bufread::GzDecoder instead.

pub fn reset(&mut self, r: R) -> R

Resets the state of this decoder entirely, swapping out the input stream for another.

This will reset the internal state of this decoder and replace the input stream with the one provided, returning the previous input stream. Future data read from this decoder will be the decompressed version of r’s data.

Note that there may be currently buffered data when this function is called, and in that case the buffered data is discarded.