Struct CompressError

struct CompressError { ... }

Error returned when a compression object is used incorrectly or otherwise generates an error.

Implementations

impl CompressError

fn message(self: &Self) -> Option<&str>

Retrieve the implementation's message about why the operation failed, if one exists.

impl Clone for CompressError

fn clone(self: &Self) -> CompressError

impl Debug for CompressError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for CompressError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Error for CompressError

impl Freeze for CompressError

impl RefUnwindSafe for CompressError

impl Send for CompressError

impl Sync for CompressError

impl Unpin for CompressError

impl UnsafeUnpin for CompressError

impl UnwindSafe for CompressError

impl<T> Any for CompressError

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for CompressError

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for CompressError

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for CompressError

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for CompressError

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for CompressError

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for CompressError

fn to_string(self: &Self) -> String

impl<T, U> Into for CompressError

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for CompressError

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for CompressError

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>