Struct DecompressError

struct DecompressError(_)

Error returned when a decompression object finds that the input stream of bytes was not a valid input stream of bytes.

Implementations

impl DecompressError

fn message(self: &Self) -> Option<&str>

Retrieve the implementation's message about why the operation failed, if one exists.

impl DecompressError

fn needs_dictionary(self: &Self) -> Option<u32>

Indicates whether decompression failed due to requiring a dictionary.

The resulting integer is the Adler-32 checksum of the dictionary required.

impl Clone for DecompressError

fn clone(self: &Self) -> DecompressError

impl Debug for DecompressError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for DecompressError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Error for DecompressError

impl Freeze for DecompressError

impl RefUnwindSafe for DecompressError

impl Send for DecompressError

impl Sync for DecompressError

impl Unpin for DecompressError

impl UnsafeUnpin for DecompressError

impl UnwindSafe for DecompressError

impl<T> Any for DecompressError

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DecompressError

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DecompressError

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DecompressError

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DecompressError

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DecompressError

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for DecompressError

fn to_string(self: &Self) -> String

impl<T, U> Into for DecompressError

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DecompressError

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DecompressError

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>