pub struct MultiGzDecoder<W: Write> { /* private fields */ }Expand description
A gzip streaming decoder that decodes a gzip file with multiple members.
This structure exposes a Write interface that will consume compressed data and
write uncompressed data to the underlying writer.
A gzip file consists of a series of members concatenated one after another.
MultiGzDecoder decodes all members of a file and writes them to the
underlying writer one after another.
To handle members separately, see GzDecoder or read more in the introduction.
Implementations
Sourceimpl<W: Write> MultiGzDecoder<W>
impl<W: Write> MultiGzDecoder<W>
Sourcepub fn new(w: W) -> MultiGzDecoder<W> ⓘ
pub fn new(w: W) -> MultiGzDecoder<W> ⓘ
Creates a new decoder which will write uncompressed data to the stream. If the gzip stream contains multiple members all will be decoded.
Sourcepub fn header(&self) -> Option<&GzHeader>
pub fn header(&self) -> Option<&GzHeader>
Returns the header associated with the current member.
Sourcepub fn get_mut(&mut self) -> &mut W
pub fn get_mut(&mut self) -> &mut W
Acquires a mutable reference to the underlying writer.
The underlying writer may be mutated or replaced as long as this preserves the bytes and ordering of the logical output stream. Concatenate output from each writer to reconstruct the complete stream.
Replacing the writer does not require flush. Call it
first to write all decompressed output currently available to the
current writer. This is useful before applying std::mem::take to
get_mut when forwarding output incrementally.
To start a new stream, call finish and create a new
decoder; replacing the writer does not reset it.
Sourcepub fn try_finish(&mut self) -> Result<()>
pub fn try_finish(&mut self) -> Result<()>
Attempt to finish this output stream, writing out final chunks of data.
Note that this function can only be used once data has finished being
written to the output stream. After this function is called then further
calls to write may result in a panic.
Panics
Attempts to write data to this stream may result in a panic after this function is called.
Errors
This function will perform I/O to finish the stream, returning any errors which happen.
Sourcepub fn finish(self) -> Result<W>
pub fn finish(self) -> Result<W>
Consumes this decoder, flushing the output stream.
This will flush the underlying data stream and then return the contained writer if the flush succeeded.
Note that this function may not be suitable to call in a situation where
the underlying stream is an asynchronous I/O stream. To finish a stream
the try_finish (or shutdown) method should be used instead. To
re-acquire ownership of a stream it is safe to call this method after
try_finish or shutdown has returned Ok.
Errors
This function will perform I/O to complete this stream, and any I/O errors which occur will be returned from this function.