Struct DeflateDecoder

struct DeflateDecoder<R> { ... }

A DEFLATE decoder, or decompressor.

This structure implements a Read interface. When read from, it reads compressed data from the underlying Read and provides the uncompressed data.

After reading a single member of the DEFLATE data this reader will return Ok(0) even if there are more bytes available in the underlying reader. DeflateDecoder may have read additional bytes past the end of the DEFLATE data. If you need the following bytes, wrap the Reader in a std::io::BufReader and use bufread::DeflateDecoder instead.

Examples

use std::io::prelude::*;
use std::io;
# use flate2::Compression;
# use flate2::write::DeflateEncoder;
use flate2::read::DeflateDecoder;

# fn main() {
#    let mut e = DeflateEncoder::new(Vec::new(), Compression::default());
#    e.write_all(b"Hello World").unwrap();
#    let bytes = e.finish().unwrap();
#    println!("{}", decode_reader(bytes).unwrap());
# }
// Uncompresses a Deflate Encoded vector of bytes and returns a string or error
// Here &[u8] implements Read
fn decode_reader(bytes: Vec<u8>) -> io::Result<String> {
   let mut deflater = DeflateDecoder::new(&bytes[..]);
   let mut s = String::new();
   deflater.read_to_string(&mut s)?;
   Ok(s)
}

Implementations

impl<R> DeflateDecoder<R>

fn reset(self: &mut Self, r: R) -> R

Resets the state of this decoder entirely, swapping out the input stream for another.

This will reset the internal state of this decoder and replace the input stream with the one provided, returning the previous input stream. Future data read from this decoder will be the decompressed version of r's data.

Note that there may be currently buffered data when this function is called, and in that case the buffered data is discarded.

fn get_ref(self: &Self) -> &R

Acquires a reference to the underlying stream

fn get_mut(self: &mut Self) -> &mut R

Acquires a mutable reference to the underlying stream

Note that mutation of the stream may result in surprising results if this decoder is continued to be used.

fn into_inner(self: Self) -> R

Consumes this decoder, returning the underlying reader.

Note that there may be buffered bytes which are not re-acquired as part of this transition. It's recommended to only call this function after EOF has been reached.

fn total_in(self: &Self) -> u64

Returns the number of bytes that the decompressor has consumed.

Note that this will likely be smaller than what the decompressor actually read from the underlying stream due to buffering.

fn total_out(self: &Self) -> u64

Returns the number of bytes that the decompressor has produced.

impl<R: Read> DeflateDecoder<R>

fn new(r: R) -> DeflateDecoder<R>

Creates a new decoder which will decompress data read from the given stream.

fn new_with_buf(r: R, buf: Vec<u8>) -> DeflateDecoder<R>

Same as new, but the intermediate buffer for data is specified.

Note that the capacity of the intermediate buffer is never increased, and it is recommended for it to be large.

impl<R> Freeze for DeflateDecoder<R>

impl<R> RefUnwindSafe for DeflateDecoder<R>

impl<R> Send for DeflateDecoder<R>

impl<R> Sync for DeflateDecoder<R>

impl<R> Unpin for DeflateDecoder<R>

impl<R> UnsafeUnpin for DeflateDecoder<R>

impl<R> UnwindSafe for DeflateDecoder<R>

impl<R: $crate::fmt::Debug> Debug for DeflateDecoder<R>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<R: Read> Read for DeflateDecoder<R>

fn read(self: &mut Self, into: &mut [u8]) -> Result<usize>

impl<T> Any for DeflateDecoder<R>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DeflateDecoder<R>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DeflateDecoder<R>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for DeflateDecoder<R>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for DeflateDecoder<R>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DeflateDecoder<R>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DeflateDecoder<R>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<W: Read + Write> Write for DeflateDecoder<W>

fn write(self: &mut Self, buf: &[u8]) -> Result<usize>
fn flush(self: &mut Self) -> Result<()>